fancyBox - Fancy jQuery Lightbox Alternative | Demonstration

# fancyBox

This is a demonstration. More information and examples: www.fancyapps.com/fancybox/

### Simple image gallery

### Different effects

### Various types

fancyBox will try to guess content type from href attribute but you can specify it directly by adding classname (fancybox.image, fancybox.iframe, etc).

- Inline
- Ajax
- Iframe
- Swf

### Etiam quis mi eu elit

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam quis mi eu elit tempor facilisis id et neque. Nulla sit amet sem sapien. Vestibulum imperdiet porta ante ac ornare. Nulla et lorem eu nibh adipiscing ultricies nec at lacus. Cras laoreet ultricies sem, at blandit mi eleifend aliquam. Nunc enim ipsum, vehicula non pretium varius, cursus ac tortor. Vivamus fringilla congue laoreet. Quisque ultrices sodales orci, quis rhoncus justo auctor in. Phasellus dui eros, bibendum eu feugiat ornare, faucibus eu mi. Nunc aliquet tempus sem, id aliquam diam varius ac. Maecenas nisl nunc, molestie vitae eleifend vel, iaculis sed magna. Aenean tempus lacus vitae orci posuere porttitor eget non felis. Donec lectus elit, aliquam nec eleifend sit amet, vestibulum sed nunc.

Ajax example will not run from your local computer and requires a server to run.

### Button helper

### Thumbnail helper

### Media helper

Will not run from your local computer, requires a server to run.

- Youtube
- Vimeo
- Metacafe
- Dailymotion
- Twitvid
- Twitpic
- Instagram

### Open manually

- Open single item
- Open single item, custom options
- Open gallery

Photo Credit: Instagrammer @whitjohns